@@ -1,26 +1,24 @@
 #!/usr/bin/php
 <?
 /*
- *  Copyright (C) 2008 Nicolas Vion <nico@picapo.net>
+ *   Copyright (C) 2008, 2009 Nicolas Vion <nico@yojik.eu>
  *
- *   This file is part of swac-explore.
- *
- *   Foobar is free software; you can redistribute it and/or modify
+ *   This file is part of Swac-explore.
+ * 
+ *   Swac-explore is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation, either version 3 of the License, or
  *   (at your option) any later version.
- *
- *   Foobar is distributed in the hope that it will be useful,
+ *   
+ *   Swac-explore is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY; without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *   GNU General Public License for more details.
- *
+ *   
  *   You should have received a copy of the GNU General Public License
- *   along with swac-explore; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *   along with Swac-explore.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 $struct_sound_info = array(
 	"Word" => array(
 		array("title" => "Text", "field" => "SWAC_TEXT", "var" => "TEXT"),
@@ -64,7 +62,7 @@ $struct_sound_info = array(
 );
 
 $struct_sounds_list = array(
-	array("field" => "SWAC_TEXT", "var" => "TEXT", "title" => "Pronunced"),
+	array("field" => "SWAC_TEXT", "var" => "TEXT", "title" => "Pronounced"),
 	array("field" => "SWAC_LANG", "var" => "LANG", "title" => "Lang.", "visible" => false),
 	array("field" => "SWAC_HOMOGRAPHIDX", "var" => "HOMOGRAPH", "title" => "Homograph"),
 	array("field" => "SWAC_BASEFORM", "var" => "BASEFORM", "title" => "Baseform", "visible" => false),
@@ -77,7 +75,7 @@ $struct_sounds_list = array(
 );
 
 $struct_select_field = array(
-	array("field" => "SWAC_TEXT", "title" => "Pronunced"),
+	array("field" => "SWAC_TEXT", "title" => "Pronounced"),
 	array("field" => "SWAC_ALPHAIDX", "title" => "Alphabetical Keys", "default" => "true"),
 	array("field" => "SWAC_TECH_DATE", "title" => "Recording Date"),
 	array("field" => "SWAC_BASEFORM", "title" => "Baseform"),
@@ -149,8 +147,8 @@ echo "#define SOUNDS_LIST_INIT".SL.RET;
 echo TAB."int count;".SL.RET;
 echo TAB."Gtk::TreeViewColumn *new_column;".SL.RET;
 foreach($struct_sounds_list as $i => $col) {
-	echo TAB.'count = treeview1->append_column("'.$col["title"].'", listview.'.$col["var"].');'.SL.RET;
-	echo TAB.'if ((new_column = treeview1->get_column(count - 1)) != NULL) {'.SL.RET;
+	echo TAB.'count = treeview1.append_column("'.$col["title"].'", listview.'.$col["var"].');'.SL.RET;
+	echo TAB.'if ((new_column = treeview1.get_column(count - 1)) != NULL) {'.SL.RET;
 	echo TAB.TAB.'new_column->set_sort_column(listview.'.$col["var"].');'.SL.RET;
 	echo TAB.TAB.'new_column->set_resizable(true);'.SL.RET;
 	if (isset($col["visible"]) and !$col["visible"])
@@ -197,7 +195,7 @@ foreach($struct_select_field as $i => $field) {
 	echo TAB.TAB.'row[listext.caption] = "'.$field["title"].'";'.SL.RET;
 	if (isset($field["default"]) and $field["default"]) { 
 		echo TAB.TAB.'user_index_field = "'.$field["field"].'";'.SL.RET;
-		echo TAB.TAB.'combobox2->set_active(row);'.SL.RET;	
+		echo TAB.TAB.'combobox2.set_active(row);'.SL.RET;	
 	}
 	echo TAB.'}'.SL.RET;
 	echo SL.RET;
